//
//  MainMenuScene.m
//
//  Copyright (c) 2013 Grantoo, LLC. All rights reserved.
//

#import "CCBReader.h"
#import "MainMenuScene.h"
#import "AppDelegate.h"
#import "GameHistory.h"
#import "SimpleAudioEngine.h"
//#import "Flurry.h"

@interface MainMenuScene () {
    CCLabelTTF          *challengeLabel;
    CCMenuItemImage    *soundOnButton;
    CCMenuItemImage    *soundOffButton;
}
- (void)setSoundButtons;
@end

@implementation MainMenuScene

- (id)init {
	if (self = [super init]) {
        CCLOG(@"MainMenuScene::alloc");
	}
	return self;
}

-(void)dealloc {
    CCLOG(@"MainMenuScene::dealloc");
   [super dealloc];
}

- (void)onExit {
    CCLOG(@"MainMenuScene::onExit");
    [[NSNotificationCenter defaultCenter] removeObserver:self];//important!!!
    [super onExit];
}


- (void)onEnter {
    CCLOG(@"MainMenuScene::onEnter");
    [super onEnter];
    [self setSoundButtons];

    // Uncomment for Flurry
    //[Flurry logEvent:@"MainMenuSceneEntry"];
        
    [[SimpleAudioEngine sharedEngine] stopBackgroundMusic];
    [[SimpleAudioEngine sharedEngine] playBackgroundMusic:@"menuBGM.mp3" loop:NO];

    [self displayChallengeCount:0];
}

- (void) goPlay:(id)sender
{
    CCLOG(@"goPlay calling stopNotification");
    // Load the game scene
    CCScene* gameScene = [CCBReader sceneWithNodeGraphFromFile:@"GameScene.ccbi"];
        
    // Go to the game scene
    [[CCDirector sharedDirector] replaceScene:gameScene];
}

- (void) goLaunch:(id)sender
{
    CCLOG(@"goLaunch calling stopNotification");
    // Uncomment for Flurry
    //[Flurry logEvent:@"SDKLaunch"];
}

- (void) goStats:(id)sender
{
    CCScene* scene = [CCBReader sceneWithNodeGraphFromFile:@"StatsScene.ccbi"];
    [[CCDirector sharedDirector] replaceScene:scene];
}

- (void) goRules:(id)sender
{
    CCScene* scene = [CCBReader sceneWithNodeGraphFromFile:@"HowToPlayScene.ccbi"];
    [[CCDirector sharedDirector] replaceScene:scene];
}

- (void) goFeedback:(id)sender
{
// Uncomment for Flurry
//    [Flurry logEvent:@"UserVoiceSelected"];
// Uncomment for UserVoice
//    AppController *app = (AppController*) [[UIApplication sharedApplication] delegate];
//    [UserVoice presentUserVoiceInterfaceForParentViewController:[app navController] andConfig:[app uvConfig]];
}

#pragma mark -
#pragma mark Private methods

- (void)displayChallengeCount:(int) challengeCount {
    if (challengeCount > 0) {
        [challengeLabel.parent setVisible:YES];
        [challengeLabel setString:[NSString stringWithFormat:@"%d", challengeCount]];
    } else {
        [challengeLabel.parent setVisible:NO];
    }
}

- (void)stopCocos
{
    CCLOG(@"MainMenuScene::stopCocos");
    [[CCDirector sharedDirector] pause];
    [[CCDirector sharedDirector] stopAnimation];
}

- (void)startCocos
{
    CCLOG(@"MainMenuScene::startCocos");
    if ([[UIApplication sharedApplication] applicationState] == UIApplicationStateActive) {
        [[CCDirector sharedDirector] startAnimation];
        [[CCDirector sharedDirector] resume];
    }
}

#pragma mark -
#pragma mark sound button functions

- (void) setSoundButtons
{
    float musicLevel = [[SimpleAudioEngine sharedEngine] backgroundMusicVolume];
    float sfxLevel = [[SimpleAudioEngine sharedEngine] effectsVolume];
    
    BOOL currentlyOn = true;
    
    if (musicLevel == 0.0f && sfxLevel == 0.0f) {
        currentlyOn = false;
    }
    
    if (currentlyOn) {
        [soundOnButton setVisible:true];
        [soundOffButton setVisible:false];
    } else {
        [soundOnButton setVisible:false];
        [soundOffButton setVisible:true];
    }
    
}

- (void) goSoundOff:(id)sender
{
    [[SimpleAudioEngine sharedEngine] setBackgroundMusicVolume:1.0f];
    [[SimpleAudioEngine sharedEngine] setEffectsVolume:1.0f];
    
    [self setSoundButtons];
}

- (void) goSoundOn:(id)sender
{
    [[SimpleAudioEngine sharedEngine] setBackgroundMusicVolume:0.0f];
    [[SimpleAudioEngine sharedEngine] setEffectsVolume:0.0f];
    
    [self setSoundButtons];
}


@end
